# Example Package

Package aws-utilities: modules with convienience functions and classes for AWS. Requires boto3. 
You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.